@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2013-2016 Horde LLC
+ * @copyright 2013-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   SessionHandler
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013-2016 Horde LLC
+ * @copyright 2013-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   SessionHandler
  */
@@ -236,7 +236,7 @@ class Horde_SessionHandler_Storage_Mongo extends Horde_SessionHandler_Storage im
                 self::MODIFIED => array(
                     '$gte' => (time() - ini_get('session.gc_maxlifetime'))
                 )
-            ), array(self::SID));
+            ), array(self::SID => true));
 
             foreach ($cursor as $val) {
                 $ids[] = $val[self::SID];
